api: get back the old API cs_disasm() & mark cs_disasm_ex() deprecated. cs_disasm_ex() will be removed in the future
diff --git a/tests/test_mips.c b/tests/test_mips.c
index 19eb7ee..c28a228 100644
--- a/tests/test_mips.c
+++ b/tests/test_mips.c
@@ -112,7 +112,7 @@
 
 		cs_option(handle, CS_OPT_DETAIL, CS_OPT_ON);
 
-		count = cs_disasm_ex(handle, platforms[i].code, platforms[i].size, address, 0, &insn);
+		count = cs_disasm(handle, platforms[i].code, platforms[i].size, address, 0, &insn);
 		if (count) {
 			size_t j;
 
@@ -127,7 +127,7 @@
 			}
 			printf("0x%"PRIx64":\n", insn[j-1].address + insn[j-1].size);
 
 			// free memory allocated by cs_disasm_ex()
 			cs_free(insn, count);
 		} else {
 			printf("****************\n");
@@ -127,7 +127,7 @@
 			printf("0x%"PRIx64":\n", insn[j-1].address + insn[j-1].size);
 
-			// free memory allocated by cs_disasm_ex()
+			// free memory allocated by cs_disasm()
 			cs_free(insn, count);
 		} else {